Developer Setup
===============

Forking PyKOALA
---------------

Forking the PyKOALA repository allows you to develop and test changes independently. Once you're ready, you can contribute back by opening a pull request to the main repository.

How to fork
^^^^^^^^^^^

To create your own fork of PyKOALA:

1. Go to the main `PyKOALA GitHub repository <https://github.com/pykoala/pykoala>`_.
2. Click the **“Fork”** button at the top right of the page.
3. GitHub will create a copy of the repository under your account, e.g., ``github.com/USERNAME/pykoala``.

.. figure:: ../_static/figures/fork_buttom.png
   :alt: GitHub "Fork" button



How to Work on Your Fork
^^^^^^^^^^^^^^^^^^^^^^^^

Once you've forked the repository, clone it to your local machine:
::

    git clone git@github.com:USERNAME/koala

Replace ``USERNAME`` with your actual GitHub username. This command downloads a complete copy of the repository to your system.

To learn more about working with forks and contributing through pull requests, refer to the official GitHub documentation `here <https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/working-with-forks/fork-a-repo>`_.
